# BANOS Fixture Comparison

## Mode 1: Python v0.2.0 vs Matlab v0.2.0

Shows Python/Matlab parity -- should be SAME

Total: 300 | SAME: 300 | NULL->VALUE: 0 | CHANGED: 0 | VALUE->NULL: 0

SAME = match NULL->VALUE = Unexpected divergence (should not occur in v0.2.0) CHANGED = Unexpected numeric mismatch VALUE->NULL = unexpected

Location | Metric | Python v0.2.0 | Matlab v0.2.0 | Status
--- | --- | --- | --- | ---
Recording_1/overall | precision | 0.928261 | 0.928261 | SAME
Recording_1/overall | recall | 0.781293 | 0.781293 | SAME
Recording_1/overall | f1_score | 0.836455 | 0.836455 | SAME
Recording_1/overall | so | 0.761228 | 0.761228 | SAME
Recording_1/overall | tp | 0.306230 | 0.306230 | SAME
Recording_1/overall | ic | 0.991718 | 0.991718 | SAME
Recording_1/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_1/group/attack | recall | 1.000000 | 1.000000 | SAME
Recording_1/group/attack | f1_score | 1.000000 | 1.000000 | SAME
Recording_1/group/attack | so | 1.000000 | 1.000000 | SAME
Recording_1/group/attack | tp | 1.000000 | 1.000000 | SAME
Recording_1/group/attack | ic | 1.000000 | 1.000000 | SAME
Recording_1/group/investigation | precision | 0.800000 | 0.800000 | SAME
Recording_1/group/investigation | recall | 0.734694 | 0.734694 | SAME
Recording_1/group/investigation | f1_score | 0.765957 | 0.765957 | SAME
Recording_1/group/investigation | so | 0.544410 | 0.544410 | SAME
Recording_1/group/investigation | tp | 0.084636 | 0.084636 | SAME
Recording_1/group/investigation | ic | 0.982941 | 0.982941 | SAME
Recording_1/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_1/group/mount | recall | 0.533333 | 0.533333 | SAME
Recording_1/group/mount | f1_score | 0.695652 | 0.695652 | SAME
Recording_1/group/mount | so | 0.733277 | 0.733277 | SAME
Recording_1/group/mount | tp | 0.078471 | 0.078471 | SAME
Recording_1/group/mount | ic | 0.990861 | 0.990861 | SAME
Recording_1/group/other | precision | 0.913043 | 0.913043 | SAME
Recording_1/group/other | recall | 0.857143 | 0.857143 | SAME
Recording_1/group/other | f1_score | 0.884211 | 0.884211 | SAME
Recording_1/group/other | so | 0.767227 | 0.767227 | SAME
Recording_1/group/other | tp | 0.061814 | 0.061814 | SAME
Recording_1/group/other | ic | 0.993069 | 0.993069 | SAME
Recording_2/overall | precision | 0.967105 | 0.967105 | SAME
Recording_2/overall | recall | 0.839924 | 0.839924 | SAME
Recording_2/overall | f1_score | 0.897301 | 0.897301 | SAME
Recording_2/overall | so | 0.825946 | 0.825946 | SAME
Recording_2/overall | tp | 0.309082 | 0.309082 | SAME
Recording_2/overall | ic | 0.993907 | 0.993907 | SAME
Recording_2/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_2/group/attack | recall | 1.000000 | 1.000000 | SAME
Recording_2/group/attack | f1_score | 1.000000 | 1.000000 | SAME
Recording_2/group/attack | so | 1.000000 | 1.000000 | SAME
Recording_2/group/attack | tp | 1.000000 | 1.000000 | SAME
Recording_2/group/attack | ic | 1.000000 | 1.000000 | SAME
Recording_2/group/investigation | precision | 0.894737 | 0.894737 | SAME
Recording_2/group/investigation | recall | 0.739130 | 0.739130 | SAME
Recording_2/group/investigation | f1_score | 0.809524 | 0.809524 | SAME
Recording_2/group/investigation | so | 0.660942 | 0.660942 | SAME
Recording_2/group/investigation | tp | 0.046151 | 0.046151 | SAME
Recording_2/group/investigation | ic | 0.989051 | 0.989051 | SAME
Recording_2/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_2/group/mount | recall | 0.833333 | 0.833333 | SAME
Recording_2/group/mount | f1_score | 0.909091 | 0.909091 | SAME
Recording_2/group/mount | so | 0.931754 | 0.931754 | SAME
Recording_2/group/mount | tp | 0.145170 | 0.145170 | SAME
Recording_2/group/mount | ic | 0.994648 | 0.994648 | SAME
Recording_2/group/other | precision | 0.973684 | 0.973684 | SAME
Recording_2/group/other | recall | 0.787234 | 0.787234 | SAME
Recording_2/group/other | f1_score | 0.870588 | 0.870588 | SAME
Recording_2/group/other | so | 0.711086 | 0.711086 | SAME
Recording_2/group/other | tp | 0.045008 | 0.045008 | SAME
Recording_2/group/other | ic | 0.991930 | 0.991930 | SAME
Recording_3/overall | precision | 0.959481 | 0.959481 | SAME
Recording_3/overall | recall | 0.850967 | 0.850967 | SAME
Recording_3/overall | f1_score | 0.898627 | 0.898627 | SAME
Recording_3/overall | so | 0.723716 | 0.723716 | SAME
Recording_3/overall | tp | 0.268876 | 0.268876 | SAME
Recording_3/overall | ic | 0.993223 | 0.993223 | SAME
Recording_3/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_3/group/attack | recall | 1.000000 | 1.000000 | SAME
Recording_3/group/attack | f1_score | 1.000000 | 1.000000 | SAME
Recording_3/group/attack | so | 1.000000 | 1.000000 | SAME
Recording_3/group/attack | tp | 1.000000 | 1.000000 | SAME
Recording_3/group/attack | ic | 1.000000 | 1.000000 | SAME
Recording_3/group/investigation | precision | 0.935484 | 0.935484 | SAME
Recording_3/group/investigation | recall | 0.783784 | 0.783784 | SAME
Recording_3/group/investigation | f1_score | 0.852941 | 0.852941 | SAME
Recording_3/group/investigation | so | 0.456310 | 0.456310 | SAME
Recording_3/group/investigation | tp | 0.022322 | 0.022322 | SAME
Recording_3/group/investigation | ic | 0.984966 | 0.984966 | SAME
Recording_3/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_3/group/mount | recall | 0.739130 | 0.739130 | SAME
Recording_3/group/mount | f1_score | 0.850000 | 0.850000 | SAME
Recording_3/group/mount | so | 0.674504 | 0.674504 | SAME
Recording_3/group/mount | tp | 0.028795 | 0.028795 | SAME
Recording_3/group/mount | ic | 0.991713 | 0.991713 | SAME
Recording_3/group/other | precision | 0.902439 | 0.902439 | SAME
Recording_3/group/other | recall | 0.880952 | 0.880952 | SAME
Recording_3/group/other | f1_score | 0.891566 | 0.891566 | SAME
Recording_3/group/other | so | 0.764048 | 0.764048 | SAME
Recording_3/group/other | tp | 0.024386 | 0.024386 | SAME
Recording_3/group/other | ic | 0.996212 | 0.996212 | SAME
Recording_4/overall | precision | 0.975000 | 0.975000 | SAME
Recording_4/overall | recall | 0.615686 | 0.615686 | SAME
Recording_4/overall | f1_score | 0.729167 | 0.729167 | SAME
Recording_4/overall | so | 0.707087 | 0.707087 | SAME
Recording_4/overall | tp | 0.275715 | 0.275715 | SAME
Recording_4/overall | ic | 0.996530 | 0.996530 | SAME
Recording_4/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_4/group/attack | recall | 1.000000 | 1.000000 | SAME
Recording_4/group/attack | f1_score | 1.000000 | 1.000000 | SAME
Recording_4/group/attack | so | 1.000000 | 1.000000 | SAME
Recording_4/group/attack | tp | 1.000000 | 1.000000 | SAME
Recording_4/group/attack | ic | 1.000000 | 1.000000 | SAME
Recording_4/group/investigation | precision | 0.900000 | 0.900000 | SAME
Recording_4/group/investigation | recall | 0.529412 | 0.529412 | SAME
Recording_4/group/investigation | f1_score | 0.666667 | 0.666667 | SAME
Recording_4/group/investigation | so | 0.391471 | 0.391471 | SAME
Recording_4/group/investigation | tp | 0.014025 | 0.014025 | SAME
Recording_4/group/investigation | ic | 0.996882 | 0.996882 | SAME
Recording_4/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_4/group/mount | recall | 0.333333 | 0.333333 | SAME
Recording_4/group/mount | f1_score | 0.500000 | 0.500000 | SAME
Recording_4/group/mount | so | 0.701119 | 0.701119 | SAME
Recording_4/group/mount | tp | 0.040087 | 0.040087 | SAME
Recording_4/group/mount | ic | 0.995289 | 0.995289 | SAME
Recording_4/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_4/group/other | recall | 0.600000 | 0.600000 | SAME
Recording_4/group/other | f1_score | 0.750000 | 0.750000 | SAME
Recording_4/group/other | so | 0.735760 | 0.735760 | SAME
Recording_4/group/other | tp | 0.048749 | 0.048749 | SAME
Recording_4/group/other | ic | 0.993949 | 0.993949 | SAME
Recording_5/overall | precision | 1.000000 | 1.000000 | SAME
Recording_5/overall | recall | 0.892105 | 0.892105 | SAME
Recording_5/overall | f1_score | 0.941459 | 0.941459 | SAME
Recording_5/overall | so | 0.836730 | 0.836730 | SAME
Recording_5/overall | tp | 0.279289 | 0.279289 | SAME
Recording_5/overall | ic | 0.995120 | 0.995120 | SAME
Recording_5/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/attack | recall | 1.000000 | 1.000000 | SAME
Recording_5/group/attack | f1_score | 1.000000 | 1.000000 | SAME
Recording_5/group/attack | so | 1.000000 | 1.000000 | SAME
Recording_5/group/attack | tp | 1.000000 | 1.000000 | SAME
Recording_5/group/attack | ic | 1.000000 | 1.000000 | SAME
Recording_5/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/investigation | recall | 0.800000 | 0.800000 | SAME
Recording_5/group/investigation | f1_score | 0.888889 | 0.888889 | SAME
Recording_5/group/investigation | so | 0.658959 | 0.658959 | SAME
Recording_5/group/investigation | tp | 0.035333 | 0.035333 | SAME
Recording_5/group/investigation | ic | 0.989914 | 0.989914 | SAME
Recording_5/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/mount | recall | 0.900000 | 0.900000 | SAME
Recording_5/group/mount | f1_score | 0.947368 | 0.947368 | SAME
Recording_5/group/mount | so | 0.910024 | 0.910024 | SAME
Recording_5/group/mount | tp | 0.035960 | 0.035960 | SAME
Recording_5/group/mount | ic | 0.996541 | 0.996541 | SAME
Recording_5/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/other | recall | 0.868421 | 0.868421 | SAME
Recording_5/group/other | f1_score | 0.929577 | 0.929577 | SAME
Recording_5/group/other | so | 0.777939 | 0.777939 | SAME
Recording_5/group/other | tp | 0.045862 | 0.045862 | SAME
Recording_5/group/other | ic | 0.994024 | 0.994024 | SAME
Recording_6/overall | precision | 0.914083 | 0.914083 | SAME
Recording_6/overall | recall | 0.745671 | 0.745671 | SAME
Recording_6/overall | f1_score | 0.792505 | 0.792505 | SAME
Recording_6/overall | so | 0.624464 | 0.624464 | SAME
Recording_6/overall | tp | 0.264068 | 0.264068 | SAME
Recording_6/overall | ic | 0.993987 | 0.993987 | SAME
Recording_6/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_6/group/attack | recall | 0.363636 | 0.363636 | SAME
Recording_6/group/attack | f1_score | 0.533333 | 0.533333 | SAME
Recording_6/group/attack | so | 0.355488 | 0.355488 | SAME
Recording_6/group/attack | tp | 0.014143 | 0.014143 | SAME
Recording_6/group/attack | ic | 0.993666 | 0.993666 | SAME
Recording_6/group/investigation | precision | 0.767442 | 0.767442 | SAME
Recording_6/group/investigation | recall | 0.785714 | 0.785714 | SAME
Recording_6/group/investigation | f1_score | 0.776471 | 0.776471 | SAME
Recording_6/group/investigation | so | 0.539580 | 0.539580 | SAME
Recording_6/group/investigation | tp | 0.020317 | 0.020317 | SAME
Recording_6/group/investigation | ic | 0.990392 | 0.990392 | SAME
Recording_6/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_6/group/mount | recall | 1.000000 | 1.000000 | SAME
Recording_6/group/mount | f1_score | 1.000000 | 1.000000 | SAME
Recording_6/group/mount | so | 1.000000 | 1.000000 | SAME
Recording_6/group/mount | tp | 1.000000 | 1.000000 | SAME
Recording_6/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_6/group/other | precision | 0.888889 | 0.888889 | SAME
Recording_6/group/other | recall | 0.833333 | 0.833333 | SAME
Recording_6/group/other | f1_score | 0.860215 | 0.860215 | SAME
Recording_6/group/other | so | 0.602789 | 0.602789 | SAME
Recording_6/group/other | tp | 0.021811 | 0.021811 | SAME
Recording_6/group/other | ic | 0.991888 | 0.991888 | SAME
Recording_7/overall | precision | 1.000000 | 1.000000 | SAME
Recording_7/overall | recall | 0.583910 | 0.583910 | SAME
Recording_7/overall | f1_score | 0.706530 | 0.706530 | SAME
Recording_7/overall | so | 0.664495 | 0.664495 | SAME
Recording_7/overall | tp | 0.276530 | 0.276530 | SAME
Recording_7/overall | ic | 0.994944 | 0.994944 | SAME
Recording_7/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/attack | recall | 0.525000 | 0.525000 | SAME
Recording_7/group/attack | f1_score | 0.688525 | 0.688525 | SAME
Recording_7/group/attack | so | 0.390695 | 0.390695 | SAME
Recording_7/group/attack | tp | 0.030229 | 0.030229 | SAME
Recording_7/group/attack | ic | 0.989471 | 0.989471 | SAME
Recording_7/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/investigation | recall | 0.300000 | 0.300000 | SAME
Recording_7/group/investigation | f1_score | 0.461538 | 0.461538 | SAME
Recording_7/group/investigation | so | 0.536495 | 0.536495 | SAME
Recording_7/group/investigation | tp | 0.031331 | 0.031331 | SAME
Recording_7/group/investigation | ic | 0.994544 | 0.994544 | SAME
Recording_7/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/mount | recall | 1.000000 | 1.000000 | SAME
Recording_7/group/mount | f1_score | 1.000000 | 1.000000 | SAME
Recording_7/group/mount | so | 1.000000 | 1.000000 | SAME
Recording_7/group/mount | tp | 1.000000 | 1.000000 | SAME
Recording_7/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_7/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/other | recall | 0.510638 | 0.510638 | SAME
Recording_7/group/other | f1_score | 0.676056 | 0.676056 | SAME
Recording_7/group/other | so | 0.730790 | 0.730790 | SAME
Recording_7/group/other | tp | 0.044561 | 0.044561 | SAME
Recording_7/group/other | ic | 0.995760 | 0.995760 | SAME
Recording_8/overall | precision | 0.891667 | 0.891667 | SAME
Recording_8/overall | recall | 0.346721 | 0.346721 | SAME
Recording_8/overall | f1_score | 0.606173 | 0.606173 | SAME
Recording_8/overall | so | 0.530562 | 0.530562 | SAME
Recording_8/overall | tp | 0.038138 | 0.038138 | SAME
Recording_8/overall | ic | 0.995577 | 0.995577 | SAME
Recording_8/group/attack | precision | 0.875000 | 0.875000 | SAME
Recording_8/group/attack | recall | 0.368421 | 0.368421 | SAME
Recording_8/group/attack | f1_score | 0.518519 | 0.518519 | SAME
Recording_8/group/attack | so | 0.268364 | 0.268364 | SAME
Recording_8/group/attack | tp | 0.020423 | 0.020423 | SAME
Recording_8/group/attack | ic | 0.991919 | 0.991919 | SAME
Recording_8/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_8/group/investigation | recall | 0.538462 | 0.538462 | SAME
Recording_8/group/investigation | f1_score | 0.700000 | 0.700000 | SAME
Recording_8/group/investigation | so | 0.591051 | 0.591051 | SAME
Recording_8/group/investigation | tp | 0.025271 | 0.025271 | SAME
Recording_8/group/investigation | ic | 0.995282 | 0.995282 | SAME
Recording_8/group/mount | precision | NaN | NaN | SAME
Recording_8/group/mount | recall | 0.000000 | 0.000000 | SAME
Recording_8/group/mount | f1_score | NaN | NaN | SAME
Recording_8/group/mount | so | NaN | NaN | SAME
Recording_8/group/mount | tp | NaN | NaN | SAME
Recording_8/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_8/group/other | precision | 0.800000 | 0.800000 | SAME
Recording_8/group/other | recall | 0.480000 | 0.480000 | SAME
Recording_8/group/other | f1_score | 0.600000 | 0.600000 | SAME
Recording_8/group/other | so | 0.732271 | 0.732271 | SAME
Recording_8/group/other | tp | 0.068721 | 0.068721 | SAME
Recording_8/group/other | ic | 0.995105 | 0.995105 | SAME
Recording_9/overall | precision | 0.798398 | 0.798398 | SAME
Recording_9/overall | recall | 0.653819 | 0.653819 | SAME
Recording_9/overall | f1_score | 0.712355 | 0.712355 | SAME
Recording_9/overall | so | 0.682730 | 0.682730 | SAME
Recording_9/overall | tp | 0.277809 | 0.277809 | SAME
Recording_9/overall | ic | 0.995671 | 0.995671 | SAME
Recording_9/group/attack | precision | 0.956522 | 0.956522 | SAME
Recording_9/group/attack | recall | 0.733333 | 0.733333 | SAME
Recording_9/group/attack | f1_score | 0.830189 | 0.830189 | SAME
Recording_9/group/attack | so | 0.424100 | 0.424100 | SAME
Recording_9/group/attack | tp | 0.020590 | 0.020590 | SAME
Recording_9/group/attack | ic | 0.989386 | 0.989386 | SAME
Recording_9/group/investigation | precision | 0.375000 | 0.375000 | SAME
Recording_9/group/investigation | recall | 0.187500 | 0.187500 | SAME
Recording_9/group/investigation | f1_score | 0.250000 | 0.250000 | SAME
Recording_9/group/investigation | so | 0.631678 | 0.631678 | SAME
Recording_9/group/investigation | tp | 0.034810 | 0.034810 | SAME
Recording_9/group/investigation | ic | 0.998630 | 0.998630 | SAME
Recording_9/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_9/group/mount | recall | 1.000000 | 1.000000 | SAME
Recording_9/group/mount | f1_score | 1.000000 | 1.000000 | SAME
Recording_9/group/mount | so | 1.000000 | 1.000000 | SAME
Recording_9/group/mount | tp | 1.000000 | 1.000000 | SAME
Recording_9/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_9/group/other | precision | 0.862069 | 0.862069 | SAME
Recording_9/group/other | recall | 0.694444 | 0.694444 | SAME
Recording_9/group/other | f1_score | 0.769231 | 0.769231 | SAME
Recording_9/group/other | so | 0.675140 | 0.675140 | SAME
Recording_9/group/other | tp | 0.055838 | 0.055838 | SAME
Recording_9/group/other | ic | 0.994669 | 0.994669 | SAME
Recording_10/overall | precision | 0.899107 | 0.899107 | SAME
Recording_10/overall | recall | 0.475760 | 0.475760 | SAME
Recording_10/overall | f1_score | 0.583475 | 0.583475 | SAME
Recording_10/overall | so | 0.666806 | 0.666806 | SAME
Recording_10/overall | tp | 0.285923 | 0.285923 | SAME
Recording_10/overall | ic | 0.996191 | 0.996191 | SAME
Recording_10/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_10/group/attack | recall | 0.285714 | 0.285714 | SAME
Recording_10/group/attack | f1_score | 0.444444 | 0.444444 | SAME
Recording_10/group/attack | so | 0.184903 | 0.184903 | SAME
Recording_10/group/attack | tp | 0.011189 | 0.011189 | SAME
Recording_10/group/attack | ic | 0.991412 | 0.991412 | SAME
Recording_10/group/investigation | precision | 0.625000 | 0.625000 | SAME
Recording_10/group/investigation | recall | 0.263158 | 0.263158 | SAME
Recording_10/group/investigation | f1_score | 0.370370 | 0.370370 | SAME
Recording_10/group/investigation | so | 0.657207 | 0.657207 | SAME
Recording_10/group/investigation | tp | 0.064683 | 0.064683 | SAME
Recording_10/group/investigation | ic | 0.995061 | 0.995061 | SAME
Recording_10/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_10/group/mount | recall | 1.000000 | 1.000000 | SAME
Recording_10/group/mount | f1_score | 1.000000 | 1.000000 | SAME
Recording_10/group/mount | so | 1.000000 | 1.000000 | SAME
Recording_10/group/mount | tp | 1.000000 | 1.000000 | SAME
Recording_10/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_10/group/other | precision | 0.971429 | 0.971429 | SAME
Recording_10/group/other | recall | 0.354167 | 0.354167 | SAME
Recording_10/group/other | f1_score | 0.519084 | 0.519084 | SAME
Recording_10/group/other | so | 0.825115 | 0.825115 | SAME
Recording_10/group/other | tp | 0.067820 | 0.067820 | SAME
Recording_10/group/other | ic | 0.998293 | 0.998293 | SAME

## Mode 2: Python v0.1.5 vs Python v0.2.0

Shows ALL changes: absent-behavior fix (0→1 correct absence) + IC bug fix

Total: 300 | SAME: 169 | NULL->VALUE: 4 | CHANGED: 127 | VALUE->NULL: 0

SAME = match NULL->VALUE = v0.1.5=0 → v0.2.0=1.0 (correct absence now scores 1) CHANGED = IC bug fix VALUE->NULL = unexpected

Location | Metric | Python v0.1.5 | Python v0.2.0 | Status
--- | --- | --- | --- | ---
Recording_1/overall | precision | 0.678261 | 0.928261 | CHANGED
Recording_1/overall | recall | 0.531293 | 0.781293 | CHANGED
Recording_1/overall | f1_score | 0.586455 | 0.836455 | CHANGED
Recording_1/overall | so | 0.511228 | 0.761228 | CHANGED
Recording_1/overall | tp | 0.056230 | 0.306230 | CHANGED
Recording_1/overall | ic | 0.737994 | 0.991718 | CHANGED
Recording_1/group/attack | precision | 0.000000 | 1.000000 | CHANGED
Recording_1/group/attack | recall | 0.000000 | 1.000000 | CHANGED
Recording_1/group/attack | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_1/group/attack | so | 0.000000 | 1.000000 | CHANGED
Recording_1/group/attack | tp | 0.000000 | 1.000000 | CHANGED
Recording_1/group/attack | ic | 0.000000 | 1.000000 | CHANGED
Recording_1/group/investigation | precision | 0.800000 | 0.800000 | SAME
Recording_1/group/investigation | recall | 0.734694 | 0.734694 | SAME
Recording_1/group/investigation | f1_score | 0.765957 | 0.765957 | SAME
Recording_1/group/investigation | so | 0.544410 | 0.544410 | SAME
Recording_1/group/investigation | tp | 0.084636 | 0.084636 | SAME
Recording_1/group/investigation | ic | 0.987641 | 0.982941 | CHANGED
Recording_1/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_1/group/mount | recall | 0.533333 | 0.533333 | SAME
Recording_1/group/mount | f1_score | 0.695652 | 0.695652 | SAME
Recording_1/group/mount | so | 0.733277 | 0.733277 | SAME
Recording_1/group/mount | tp | 0.078471 | 0.078471 | SAME
Recording_1/group/mount | ic | 0.990861 | 0.990861 | SAME
Recording_1/group/other | precision | 0.913043 | 0.913043 | SAME
Recording_1/group/other | recall | 0.857143 | 0.857143 | SAME
Recording_1/group/other | f1_score | 0.884211 | 0.884211 | SAME
Recording_1/group/other | so | 0.767227 | 0.767227 | SAME
Recording_1/group/other | tp | 0.061814 | 0.061814 | SAME
Recording_1/group/other | ic | 0.973473 | 0.993069 | CHANGED
Recording_2/overall | precision | 0.717105 | 0.967105 | CHANGED
Recording_2/overall | recall | 0.589924 | 0.839924 | CHANGED
Recording_2/overall | f1_score | 0.647301 | 0.897301 | CHANGED
Recording_2/overall | so | 0.575946 | 0.825946 | CHANGED
Recording_2/overall | tp | 0.059082 | 0.309082 | CHANGED
Recording_2/overall | ic | 0.744498 | 0.993907 | CHANGED
Recording_2/group/attack | precision | 0.000000 | 1.000000 | CHANGED
Recording_2/group/attack | recall | 0.000000 | 1.000000 | CHANGED
Recording_2/group/attack | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_2/group/attack | so | 0.000000 | 1.000000 | CHANGED
Recording_2/group/attack | tp | 0.000000 | 1.000000 | CHANGED
Recording_2/group/attack | ic | 0.000000 | 1.000000 | CHANGED
Recording_2/group/investigation | precision | 0.894737 | 0.894737 | SAME
Recording_2/group/investigation | recall | 0.739130 | 0.739130 | SAME
Recording_2/group/investigation | f1_score | 0.809524 | 0.809524 | SAME
Recording_2/group/investigation | so | 0.660942 | 0.660942 | SAME
Recording_2/group/investigation | tp | 0.046151 | 0.046151 | SAME
Recording_2/group/investigation | ic | 0.991219 | 0.989051 | CHANGED
Recording_2/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_2/group/mount | recall | 0.833333 | 0.833333 | SAME
Recording_2/group/mount | f1_score | 0.909091 | 0.909091 | SAME
Recording_2/group/mount | so | 0.931754 | 0.931754 | SAME
Recording_2/group/mount | tp | 0.145170 | 0.145170 | SAME
Recording_2/group/mount | ic | 0.994648 | 0.994648 | SAME
Recording_2/group/other | precision | 0.973684 | 0.973684 | SAME
Recording_2/group/other | recall | 0.787234 | 0.787234 | SAME
Recording_2/group/other | f1_score | 0.870588 | 0.870588 | SAME
Recording_2/group/other | so | 0.711086 | 0.711086 | SAME
Recording_2/group/other | tp | 0.045008 | 0.045008 | SAME
Recording_2/group/other | ic | 0.992125 | 0.991930 | CHANGED
Recording_3/overall | precision | 0.709481 | 0.959481 | CHANGED
Recording_3/overall | recall | 0.600967 | 0.850967 | CHANGED
Recording_3/overall | f1_score | 0.648627 | 0.898627 | CHANGED
Recording_3/overall | so | 0.473716 | 0.723716 | CHANGED
Recording_3/overall | tp | 0.018876 | 0.268876 | CHANGED
Recording_3/overall | ic | 0.737293 | 0.993223 | CHANGED
Recording_3/group/attack | precision | 0.000000 | 1.000000 | CHANGED
Recording_3/group/attack | recall | 0.000000 | 1.000000 | CHANGED
Recording_3/group/attack | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_3/group/attack | so | 0.000000 | 1.000000 | CHANGED
Recording_3/group/attack | tp | 0.000000 | 1.000000 | CHANGED
Recording_3/group/attack | ic | 0.000000 | 1.000000 | CHANGED
Recording_3/group/investigation | precision | 0.935484 | 0.935484 | SAME
Recording_3/group/investigation | recall | 0.783784 | 0.783784 | SAME
Recording_3/group/investigation | f1_score | 0.852941 | 0.852941 | SAME
Recording_3/group/investigation | so | 0.456310 | 0.456310 | SAME
Recording_3/group/investigation | tp | 0.022322 | 0.022322 | SAME
Recording_3/group/investigation | ic | 0.984966 | 0.984966 | SAME
Recording_3/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_3/group/mount | recall | 0.739130 | 0.739130 | SAME
Recording_3/group/mount | f1_score | 0.850000 | 0.850000 | SAME
Recording_3/group/mount | so | 0.674504 | 0.674504 | SAME
Recording_3/group/mount | tp | 0.028795 | 0.028795 | SAME
Recording_3/group/mount | ic | 0.991713 | 0.991713 | SAME
Recording_3/group/other | precision | 0.902439 | 0.902439 | SAME
Recording_3/group/other | recall | 0.880952 | 0.880952 | SAME
Recording_3/group/other | f1_score | 0.891566 | 0.891566 | SAME
Recording_3/group/other | so | 0.764048 | 0.764048 | SAME
Recording_3/group/other | tp | 0.024386 | 0.024386 | SAME
Recording_3/group/other | ic | 0.972492 | 0.996212 | CHANGED
Recording_4/overall | precision | 0.725000 | 0.975000 | CHANGED
Recording_4/overall | recall | 0.365686 | 0.615686 | CHANGED
Recording_4/overall | f1_score | 0.479167 | 0.729167 | CHANGED
Recording_4/overall | so | 0.457087 | 0.707087 | CHANGED
Recording_4/overall | tp | 0.025715 | 0.275715 | CHANGED
Recording_4/overall | ic | 0.736591 | 0.996530 | CHANGED
Recording_4/group/attack | precision | 0.000000 | 1.000000 | CHANGED
Recording_4/group/attack | recall | 0.000000 | 1.000000 | CHANGED
Recording_4/group/attack | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_4/group/attack | so | 0.000000 | 1.000000 | CHANGED
Recording_4/group/attack | tp | 0.000000 | 1.000000 | CHANGED
Recording_4/group/attack | ic | 0.000000 | 1.000000 | CHANGED
Recording_4/group/investigation | precision | 0.900000 | 0.900000 | SAME
Recording_4/group/investigation | recall | 0.529412 | 0.529412 | SAME
Recording_4/group/investigation | f1_score | 0.666667 | 0.666667 | SAME
Recording_4/group/investigation | so | 0.391471 | 0.391471 | SAME
Recording_4/group/investigation | tp | 0.014025 | 0.014025 | SAME
Recording_4/group/investigation | ic | 0.996882 | 0.996882 | SAME
Recording_4/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_4/group/mount | recall | 0.333333 | 0.333333 | SAME
Recording_4/group/mount | f1_score | 0.500000 | 0.500000 | SAME
Recording_4/group/mount | so | 0.701119 | 0.701119 | SAME
Recording_4/group/mount | tp | 0.040087 | 0.040087 | SAME
Recording_4/group/mount | ic | 0.995289 | 0.995289 | SAME
Recording_4/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_4/group/other | recall | 0.600000 | 0.600000 | SAME
Recording_4/group/other | f1_score | 0.750000 | 0.750000 | SAME
Recording_4/group/other | so | 0.735760 | 0.735760 | SAME
Recording_4/group/other | tp | 0.048749 | 0.048749 | SAME
Recording_4/group/other | ic | 0.954191 | 0.993949 | CHANGED
Recording_5/overall | precision | 0.750000 | 1.000000 | CHANGED
Recording_5/overall | recall | 0.642105 | 0.892105 | CHANGED
Recording_5/overall | f1_score | 0.691459 | 0.941459 | CHANGED
Recording_5/overall | so | 0.586730 | 0.836730 | CHANGED
Recording_5/overall | tp | 0.029289 | 0.279289 | CHANGED
Recording_5/overall | ic | 0.732165 | 0.995120 | CHANGED
Recording_5/group/attack | precision | 0.000000 | 1.000000 | CHANGED
Recording_5/group/attack | recall | 0.000000 | 1.000000 | CHANGED
Recording_5/group/attack | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_5/group/attack | so | 0.000000 | 1.000000 | CHANGED
Recording_5/group/attack | tp | 0.000000 | 1.000000 | CHANGED
Recording_5/group/attack | ic | 0.000000 | 1.000000 | CHANGED
Recording_5/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/investigation | recall | 0.800000 | 0.800000 | SAME
Recording_5/group/investigation | f1_score | 0.888889 | 0.888889 | SAME
Recording_5/group/investigation | so | 0.658959 | 0.658959 | SAME
Recording_5/group/investigation | tp | 0.035333 | 0.035333 | SAME
Recording_5/group/investigation | ic | 0.990205 | 0.989914 | CHANGED
Recording_5/group/mount | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/mount | recall | 0.900000 | 0.900000 | SAME
Recording_5/group/mount | f1_score | 0.947368 | 0.947368 | SAME
Recording_5/group/mount | so | 0.910024 | 0.910024 | SAME
Recording_5/group/mount | tp | 0.035960 | 0.035960 | SAME
Recording_5/group/mount | ic | 0.996541 | 0.996541 | SAME
Recording_5/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_5/group/other | recall | 0.868421 | 0.868421 | SAME
Recording_5/group/other | f1_score | 0.929577 | 0.929577 | SAME
Recording_5/group/other | so | 0.777939 | 0.777939 | SAME
Recording_5/group/other | tp | 0.045862 | 0.045862 | SAME
Recording_5/group/other | ic | 0.941915 | 0.994024 | CHANGED
Recording_6/overall | precision | 0.664083 | 0.914083 | CHANGED
Recording_6/overall | recall | 0.495671 | 0.745671 | CHANGED
Recording_6/overall | f1_score | 0.542505 | 0.792505 | CHANGED
Recording_6/overall | so | 0.374464 | 0.624464 | CHANGED
Recording_6/overall | tp | 0.014068 | 0.264068 | CHANGED
Recording_6/overall | ic | 0.738821 | 0.993987 | CHANGED
Recording_6/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_6/group/attack | recall | 0.363636 | 0.363636 | SAME
Recording_6/group/attack | f1_score | 0.533333 | 0.533333 | SAME
Recording_6/group/attack | so | 0.355488 | 0.355488 | SAME
Recording_6/group/attack | tp | 0.014143 | 0.014143 | SAME
Recording_6/group/attack | ic | 0.993666 | 0.993666 | SAME
Recording_6/group/investigation | precision | 0.767442 | 0.767442 | SAME
Recording_6/group/investigation | recall | 0.785714 | 0.785714 | SAME
Recording_6/group/investigation | f1_score | 0.776471 | 0.776471 | SAME
Recording_6/group/investigation | so | 0.539580 | 0.539580 | SAME
Recording_6/group/investigation | tp | 0.020317 | 0.020317 | SAME
Recording_6/group/investigation | ic | 0.990392 | 0.990392 | SAME
Recording_6/group/mount | precision | 0.000000 | 1.000000 | CHANGED
Recording_6/group/mount | recall | 0.000000 | 1.000000 | CHANGED
Recording_6/group/mount | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_6/group/mount | so | 0.000000 | 1.000000 | CHANGED
Recording_6/group/mount | tp | 0.000000 | 1.000000 | CHANGED
Recording_6/group/mount | ic | 0.000000 | 1.000000 | CHANGED
Recording_6/group/other | precision | 0.888889 | 0.888889 | SAME
Recording_6/group/other | recall | 0.833333 | 0.833333 | SAME
Recording_6/group/other | f1_score | 0.860215 | 0.860215 | SAME
Recording_6/group/other | so | 0.602789 | 0.602789 | SAME
Recording_6/group/other | tp | 0.021811 | 0.021811 | SAME
Recording_6/group/other | ic | 0.971224 | 0.991888 | CHANGED
Recording_7/overall | precision | 0.750000 | 1.000000 | CHANGED
Recording_7/overall | recall | 0.333910 | 0.583910 | CHANGED
Recording_7/overall | f1_score | 0.456530 | 0.706530 | CHANGED
Recording_7/overall | so | 0.414495 | 0.664495 | CHANGED
Recording_7/overall | tp | 0.026530 | 0.276530 | CHANGED
Recording_7/overall | ic | 0.734494 | 0.994944 | CHANGED
Recording_7/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/attack | recall | 0.525000 | 0.525000 | SAME
Recording_7/group/attack | f1_score | 0.688525 | 0.688525 | SAME
Recording_7/group/attack | so | 0.390695 | 0.390695 | SAME
Recording_7/group/attack | tp | 0.030229 | 0.030229 | SAME
Recording_7/group/attack | ic | 0.989471 | 0.989471 | SAME
Recording_7/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/investigation | recall | 0.300000 | 0.300000 | SAME
Recording_7/group/investigation | f1_score | 0.461538 | 0.461538 | SAME
Recording_7/group/investigation | so | 0.536495 | 0.536495 | SAME
Recording_7/group/investigation | tp | 0.031331 | 0.031331 | SAME
Recording_7/group/investigation | ic | 0.994544 | 0.994544 | SAME
Recording_7/group/mount | precision | 0.000000 | 1.000000 | CHANGED
Recording_7/group/mount | recall | 0.000000 | 1.000000 | CHANGED
Recording_7/group/mount | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_7/group/mount | so | 0.000000 | 1.000000 | CHANGED
Recording_7/group/mount | tp | 0.000000 | 1.000000 | CHANGED
Recording_7/group/mount | ic | 0.000000 | 1.000000 | CHANGED
Recording_7/group/other | precision | 1.000000 | 1.000000 | SAME
Recording_7/group/other | recall | 0.510638 | 0.510638 | SAME
Recording_7/group/other | f1_score | 0.676056 | 0.676056 | SAME
Recording_7/group/other | so | 0.730790 | 0.730790 | SAME
Recording_7/group/other | tp | 0.044561 | 0.044561 | SAME
Recording_7/group/other | ic | 0.953960 | 0.995760 | CHANGED
Recording_8/overall | precision | 0.668750 | 0.891667 | CHANGED
Recording_8/overall | recall | 0.346721 | 0.346721 | SAME
Recording_8/overall | f1_score | 0.454630 | 0.606173 | CHANGED
Recording_8/overall | so | 0.397921 | 0.530562 | CHANGED
Recording_8/overall | tp | 0.028604 | 0.038138 | CHANGED
Recording_8/overall | ic | 0.965943 | 0.995577 | CHANGED
Recording_8/group/attack | precision | 0.875000 | 0.875000 | SAME
Recording_8/group/attack | recall | 0.368421 | 0.368421 | SAME
Recording_8/group/attack | f1_score | 0.518519 | 0.518519 | SAME
Recording_8/group/attack | so | 0.268364 | 0.268364 | SAME
Recording_8/group/attack | tp | 0.020423 | 0.020423 | SAME
Recording_8/group/attack | ic | 0.992796 | 0.991919 | CHANGED
Recording_8/group/investigation | precision | 1.000000 | 1.000000 | SAME
Recording_8/group/investigation | recall | 0.538462 | 0.538462 | SAME
Recording_8/group/investigation | f1_score | 0.700000 | 0.700000 | SAME
Recording_8/group/investigation | so | 0.591051 | 0.591051 | SAME
Recording_8/group/investigation | tp | 0.025271 | 0.025271 | SAME
Recording_8/group/investigation | ic | 0.995282 | 0.995282 | SAME
Recording_8/group/mount | precision | 0.000000 | NaN | NULL->VALUE
Recording_8/group/mount | recall | 0.000000 | 0.000000 | SAME
Recording_8/group/mount | f1_score | 0.000000 | NaN | NULL->VALUE
Recording_8/group/mount | so | 0.000000 | NaN | NULL->VALUE
Recording_8/group/mount | tp | 0.000000 | NaN | NULL->VALUE
Recording_8/group/mount | ic | 1.000000 | 1.000000 | SAME
Recording_8/group/other | precision | 0.800000 | 0.800000 | SAME
Recording_8/group/other | recall | 0.480000 | 0.480000 | SAME
Recording_8/group/other | f1_score | 0.600000 | 0.600000 | SAME
Recording_8/group/other | so | 0.732271 | 0.732271 | SAME
Recording_8/group/other | tp | 0.068721 | 0.068721 | SAME
Recording_8/group/other | ic | 0.875693 | 0.995105 | CHANGED
Recording_9/overall | precision | 0.548398 | 0.798398 | CHANGED
Recording_9/overall | recall | 0.403819 | 0.653819 | CHANGED
Recording_9/overall | f1_score | 0.462355 | 0.712355 | CHANGED
Recording_9/overall | so | 0.432730 | 0.682730 | CHANGED
Recording_9/overall | tp | 0.027809 | 0.277809 | CHANGED
Recording_9/overall | ic | 0.738825 | 0.995671 | CHANGED
Recording_9/group/attack | precision | 0.956522 | 0.956522 | SAME
Recording_9/group/attack | recall | 0.733333 | 0.733333 | SAME
Recording_9/group/attack | f1_score | 0.830189 | 0.830189 | SAME
Recording_9/group/attack | so | 0.424100 | 0.424100 | SAME
Recording_9/group/attack | tp | 0.020590 | 0.020590 | SAME
Recording_9/group/attack | ic | 0.989386 | 0.989386 | SAME
Recording_9/group/investigation | precision | 0.375000 | 0.375000 | SAME
Recording_9/group/investigation | recall | 0.187500 | 0.187500 | SAME
Recording_9/group/investigation | f1_score | 0.250000 | 0.250000 | SAME
Recording_9/group/investigation | so | 0.631678 | 0.631678 | SAME
Recording_9/group/investigation | tp | 0.034810 | 0.034810 | SAME
Recording_9/group/investigation | ic | 0.998630 | 0.998630 | SAME
Recording_9/group/mount | precision | 0.000000 | 1.000000 | CHANGED
Recording_9/group/mount | recall | 0.000000 | 1.000000 | CHANGED
Recording_9/group/mount | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_9/group/mount | so | 0.000000 | 1.000000 | CHANGED
Recording_9/group/mount | tp | 0.000000 | 1.000000 | CHANGED
Recording_9/group/mount | ic | 0.000000 | 1.000000 | CHANGED
Recording_9/group/other | precision | 0.862069 | 0.862069 | SAME
Recording_9/group/other | recall | 0.694444 | 0.694444 | SAME
Recording_9/group/other | f1_score | 0.769231 | 0.769231 | SAME
Recording_9/group/other | so | 0.675140 | 0.675140 | SAME
Recording_9/group/other | tp | 0.055838 | 0.055838 | SAME
Recording_9/group/other | ic | 0.967283 | 0.994669 | CHANGED
Recording_10/overall | precision | 0.649107 | 0.899107 | CHANGED
Recording_10/overall | recall | 0.225760 | 0.475760 | CHANGED
Recording_10/overall | f1_score | 0.333475 | 0.583475 | CHANGED
Recording_10/overall | so | 0.416806 | 0.666806 | CHANGED
Recording_10/overall | tp | 0.035923 | 0.285923 | CHANGED
Recording_10/overall | ic | 0.741064 | 0.996191 | CHANGED
Recording_10/group/attack | precision | 1.000000 | 1.000000 | SAME
Recording_10/group/attack | recall | 0.285714 | 0.285714 | SAME
Recording_10/group/attack | f1_score | 0.444444 | 0.444444 | SAME
Recording_10/group/attack | so | 0.184903 | 0.184903 | SAME
Recording_10/group/attack | tp | 0.011189 | 0.011189 | SAME
Recording_10/group/attack | ic | 0.991412 | 0.991412 | SAME
Recording_10/group/investigation | precision | 0.625000 | 0.625000 | SAME
Recording_10/group/investigation | recall | 0.263158 | 0.263158 | SAME
Recording_10/group/investigation | f1_score | 0.370370 | 0.370370 | SAME
Recording_10/group/investigation | so | 0.657207 | 0.657207 | SAME
Recording_10/group/investigation | tp | 0.064683 | 0.064683 | SAME
Recording_10/group/investigation | ic | 0.995061 | 0.995061 | SAME
Recording_10/group/mount | precision | 0.000000 | 1.000000 | CHANGED
Recording_10/group/mount | recall | 0.000000 | 1.000000 | CHANGED
Recording_10/group/mount | f1_score | 0.000000 | 1.000000 | CHANGED
Recording_10/group/mount | so | 0.000000 | 1.000000 | CHANGED
Recording_10/group/mount | tp | 0.000000 | 1.000000 | CHANGED
Recording_10/group/mount | ic | 0.000000 | 1.000000 | CHANGED
Recording_10/group/other | precision | 0.971429 | 0.971429 | SAME
Recording_10/group/other | recall | 0.354167 | 0.354167 | SAME
Recording_10/group/other | f1_score | 0.519084 | 0.519084 | SAME
Recording_10/group/other | so | 0.825115 | 0.825115 | SAME
Recording_10/group/other | tp | 0.067820 | 0.067820 | SAME
Recording_10/group/other | ic | 0.977784 | 0.998293 | CHANGED